@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -24,7 +24,8 @@
 #include "IDatabaseFactory.h"
 #include "StatementLocation.h"
 
-#include <Core/Enumerations.h>
+#include <Compatibility.h>  // For std::unique_ptr<>
+#include <Enumerations.h>
 
 #include <boost/thread/recursive_mutex.hpp>
 #include <memory>
@@ -37,9 +38,9 @@ namespace OrthancDatabases
     typedef std::map<StatementLocation, IPrecompiledStatement*>  CachedStatements;
 
     boost::recursive_mutex           mutex_;
-    std::auto_ptr<IDatabaseFactory>  factory_;
-    std::auto_ptr<IDatabase>         database_;
-    std::auto_ptr<ITransaction>      transaction_;
+    std::unique_ptr<IDatabaseFactory>  factory_;
+    std::unique_ptr<IDatabase>         database_;
+    std::unique_ptr<ITransaction>      transaction_;
     CachedStatements                 cachedStatements_;
     Dialect                          dialect_;
 
@@ -117,8 +118,8 @@ namespace OrthancDatabases
       DatabaseManager&                     manager_;
       boost::recursive_mutex::scoped_lock  lock_;
       ITransaction&                        transaction_;
-      std::auto_ptr<Query>                 query_;
-      std::auto_ptr<IResult>               result_;
+      std::unique_ptr<Query>                 query_;
+      std::unique_ptr<IResult>               result_;
 
       IResult& GetResult() const;
 
@@ -200,7 +201,7 @@ namespace OrthancDatabases
     class StandaloneStatement : public StatementBase
     {
     private:
-      std::auto_ptr<IPrecompiledStatement>  statement_;
+      std::unique_ptr<IPrecompiledStatement>  statement_;
       
     public:
       StandaloneStatement(DatabaseManager& manager,
