@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,15 +21,15 @@
 
 #include "IndexBackend.h"
 
+#include "../../Resources/Orthanc/Databases/ISqlLookupFormatter.h"
 #include "../Common/BinaryStringValue.h"
 #include "../Common/Integer64Value.h"
 #include "../Common/Utf8StringValue.h"
 #include "GlobalProperties.h"
 
-#include <Core/Logging.h>
-#include <Core/OrthancException.h>
-#include <OrthancServer/ServerEnumerations.h>
-#include <OrthancServer/Search/ISqlLookupFormatter.h>
+#include <Compatibility.h>  // For std::unique_ptr<>
+#include <Logging.h>
+#include <OrthancException.h>
 
 
 namespace OrthancDatabases
@@ -693,7 +693,7 @@ namespace OrthancDatabases
     
   uint64_t IndexBackend::GetResourceCount(OrthancPluginResourceType resourceType)
   {
-    std::auto_ptr<DatabaseManager::CachedStatement> statement;
+    std::unique_ptr<DatabaseManager::CachedStatement> statement;
 
     switch (manager_.GetDialect())
     {
@@ -758,7 +758,7 @@ namespace OrthancDatabases
     
   uint64_t IndexBackend::GetTotalCompressedSize()
   {
-    std::auto_ptr<DatabaseManager::CachedStatement> statement;
+    std::unique_ptr<DatabaseManager::CachedStatement> statement;
 
     // NB: "COALESCE" is used to replace "NULL" by "0" if the number of rows is empty
 
@@ -795,7 +795,7 @@ namespace OrthancDatabases
     
   uint64_t IndexBackend::GetTotalUncompressedSize()
   {
-    std::auto_ptr<DatabaseManager::CachedStatement> statement;
+    std::unique_ptr<DatabaseManager::CachedStatement> statement;
 
     // NB: "COALESCE" is used to replace "NULL" by "0" if the number of rows is empty
 
@@ -1010,7 +1010,7 @@ namespace OrthancDatabases
                                       OrthancPluginIdentifierConstraint constraint,
                                       const char* value)
   {
-    std::auto_ptr<DatabaseManager::CachedStatement> statement;
+    std::unique_ptr<DatabaseManager::CachedStatement> statement;
 
     std::string header =
       "SELECT d.id FROM DicomIdentifiers AS d, Resources AS r WHERE "
@@ -1466,7 +1466,7 @@ namespace OrthancDatabases
   // For unit testing only!
   uint64_t IndexBackend::GetResourcesCount()
   {
-    std::auto_ptr<DatabaseManager::CachedStatement> statement;
+    std::unique_ptr<DatabaseManager::CachedStatement> statement;
 
     switch (manager_.GetDialect())
     {
@@ -1502,7 +1502,7 @@ namespace OrthancDatabases
   // For unit testing only!
   uint64_t IndexBackend::GetUnprotectedPatientsCount()
   {
-    std::auto_ptr<DatabaseManager::CachedStatement> statement;
+    std::unique_ptr<DatabaseManager::CachedStatement> statement;
 
     switch (manager_.GetDialect())
     {
