@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -37,8 +37,9 @@
 #endif
 
 
-#include <Core/OrthancException.h>
-#include <OrthancServer/Search/DatabaseConstraint.h>
+#include "../../Resources/Orthanc/Databases/DatabaseConstraint.h"
+
+#include <OrthancException.h>
 
 
 
