@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -25,7 +25,7 @@
 #  error PostgreSQL support must be enabled to use this file
 #endif
 
-#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
+#include "../../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
 
 namespace OrthancDatabases
 {
@@ -40,6 +40,8 @@ namespace OrthancDatabases
     std::string  uri_;
     bool         ssl_;
     bool         lock_;
+    unsigned int maxConnectionRetries_;
+    unsigned int connectionRetryInterval_;
 
     void Reset();
 
@@ -112,6 +114,16 @@ namespace OrthancDatabases
       return lock_;
     }
 
+    unsigned int GetMaxConnectionRetries() const
+    {
+      return maxConnectionRetries_;
+    }
+
+    unsigned int GetConnectionRetryInterval() const
+    {
+      return connectionRetryInterval_;
+    }
+
     void Format(std::string& target) const;
   };
 }
