@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -28,9 +28,10 @@
 #include "../Common/NullValue.h"
 #include "../Common/Utf8StringValue.h"
 
-#include <Core/OrthancException.h>
-#include <Core/Logging.h>
-#include <Core/Endianness.h>
+#include <Compatibility.h>  // For std::unique_ptr<>
+#include <OrthancException.h>
+#include <Logging.h>
+#include <Endianness.h>
 
 #include <cassert>
 #include <boost/lexical_cast.hpp>
@@ -230,7 +231,7 @@ namespace OrthancDatabases
 
       case OIDOID:
       {
-        std::auto_ptr<FileValue> value(new FileValue);
+        std::unique_ptr<FileValue> value(new FileValue);
         GetLargeObject(value->GetContent(), column);
         return value.release();
       }
