@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -22,9 +22,10 @@
 #include "PostgreSQLIndex.h"
 #include "../../Framework/Plugins/PluginInitialization.h"
 
-#include <Core/Logging.h>
+#include <Compatibility.h>  // For std::unique_ptr<>
+#include <Logging.h>
 
-static std::auto_ptr<OrthancDatabases::PostgreSQLIndex> backend_;
+static std::unique_ptr<OrthancDatabases::PostgreSQLIndex> backend_;
 
 
 extern "C"
