@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -49,6 +49,12 @@ namespace OrthancDatabases
       {
         return that_.OpenInternal();
       }
+
+      virtual void GetConnectionRetriesParameters(unsigned int& maxConnectionRetries, unsigned int& connectionRetryInterval)
+      {
+        maxConnectionRetries = that_.parameters_.GetMaxConnectionRetries();
+        connectionRetryInterval = that_.parameters_.GetConnectionRetryInterval();
+      }
     };
 
     OrthancPluginContext*  context_;
