@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -20,47 +20,53 @@
 
 
 #include "PostgreSQLStorageArea.h"
+#include "PostgreSQLDefinitions.h"
 
 #include "../../Framework/PostgreSQL/PostgreSQLTransaction.h"
+#include "../../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
 
-#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
-#include <Core/Logging.h>
+#include <Compatibility.h>  // For std::unique_ptr<>
+#include <Logging.h>
 
 
 namespace OrthancDatabases
 {
   IDatabase* PostgreSQLStorageArea::OpenInternal()
   {
-    std::auto_ptr<PostgreSQLDatabase> db(new PostgreSQLDatabase(parameters_));
+    std::unique_ptr<PostgreSQLDatabase> db(new PostgreSQLDatabase(parameters_));
 
     db->Open();
 
     if (parameters_.HasLock())
     {
-      db->AdvisoryLock(43 /* some arbitrary constant */);
-    }
-
-    if (clearAll_)
-    {
-      db->ClearAll();
+      db->AdvisoryLock(POSTGRESQL_LOCK_STORAGE);
     }
 
     {
-      PostgreSQLTransaction t(*db);
+      PostgreSQLDatabase::TransientAdvisoryLock lock(*db, POSTGRESQL_LOCK_DATABASE_SETUP);
 
-      if (!db->DoesTableExist("StorageArea"))
+      if (clearAll_)
       {
-        db->Execute("CREATE TABLE IF NOT EXISTS StorageArea("
-                    "uuid VARCHAR NOT NULL PRIMARY KEY,"
-                    "content OID NOT NULL,"
-                    "type INTEGER NOT NULL)");
-
-        // Automatically remove the large objects associated with the table
-        db->Execute("CREATE OR REPLACE RULE StorageAreaDelete AS ON DELETE "
-                    "TO StorageArea DO SELECT lo_unlink(old.content);");
+        db->ClearAll();
       }
 
-      t.Commit();
+      {
+        PostgreSQLTransaction t(*db);
+
+        if (!db->DoesTableExist("StorageArea"))
+        {
+          db->Execute("CREATE TABLE IF NOT EXISTS StorageArea("
+                      "uuid VARCHAR NOT NULL PRIMARY KEY,"
+                      "content OID NOT NULL,"
+                      "type INTEGER NOT NULL)");
+
+          // Automatically remove the large objects associated with the table
+          db->Execute("CREATE OR REPLACE RULE StorageAreaDelete AS ON DELETE "
+                      "TO StorageArea DO SELECT lo_unlink(old.content);");
+        }
+
+        t.Commit();
+      }
     }
 
     return db.release();
