@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -34,13 +34,15 @@
 #  undef S_IXOTH
 #endif
 
+#include "../../Framework/Plugins/GlobalProperties.h"
+#include "../../Framework/PostgreSQL/PostgreSQLLargeObject.h"
+#include "../../Framework/PostgreSQL/PostgreSQLResult.h"
+#include "../../Framework/PostgreSQL/PostgreSQLTransaction.h"
 #include "../Plugins/PostgreSQLIndex.h"
 #include "../Plugins/PostgreSQLStorageArea.h"
-#include "../../Framework/PostgreSQL/PostgreSQLTransaction.h"
-#include "../../Framework/PostgreSQL/PostgreSQLResult.h"
-#include "../../Framework/PostgreSQL/PostgreSQLLargeObject.h"
 
-#include <Core/OrthancException.h>
+#include <Compatibility.h>  // For std::unique_ptr<>
+#include <OrthancException.h>
 
 #include <boost/lexical_cast.hpp>
 
@@ -51,7 +53,7 @@ extern PostgreSQLParameters  globalParameters_;
 
 static PostgreSQLDatabase* CreateTestDatabase()
 {
-  std::auto_ptr<PostgreSQLDatabase> pg
+  std::unique_ptr<PostgreSQLDatabase> pg
     (new PostgreSQLDatabase(globalParameters_));
 
   pg->Open();
@@ -72,7 +74,7 @@ static int64_t CountLargeObjects(PostgreSQLDatabase& db)
 
 TEST(PostgreSQL, Basic)
 {
-  std::auto_ptr<PostgreSQLDatabase> pg(CreateTestDatabase());
+  std::unique_ptr<PostgreSQLDatabase> pg(CreateTestDatabase());
 
   ASSERT_FALSE(pg->DoesTableExist("Test"));
   pg->Execute("CREATE TABLE Test(name INTEGER, value BIGINT)");
@@ -145,7 +147,7 @@ TEST(PostgreSQL, Basic)
 
 TEST(PostgreSQL, String)
 {
-  std::auto_ptr<PostgreSQLDatabase> pg(CreateTestDatabase());
+  std::unique_ptr<PostgreSQLDatabase> pg(CreateTestDatabase());
 
   pg->Execute("CREATE TABLE Test(name INTEGER, value VARCHAR(40))");
 
@@ -191,7 +193,7 @@ TEST(PostgreSQL, String)
 
 TEST(PostgreSQL, Transaction)
 {
-  std::auto_ptr<PostgreSQLDatabase> pg(CreateTestDatabase());
+  std::unique_ptr<PostgreSQLDatabase> pg(CreateTestDatabase());
 
   pg->Execute("CREATE TABLE Test(name INTEGER, value INTEGER)");
 
@@ -259,7 +261,7 @@ TEST(PostgreSQL, Transaction)
 
 TEST(PostgreSQL, LargeObject)
 {
-  std::auto_ptr<PostgreSQLDatabase> pg(CreateTestDatabase());
+  std::unique_ptr<PostgreSQLDatabase> pg(CreateTestDatabase());
   ASSERT_EQ(0, CountLargeObjects(*pg));
 
   pg->Execute("CREATE TABLE Test(name VARCHAR, value OID)");
@@ -396,21 +398,21 @@ TEST(PostgreSQL, StorageArea)
 
 TEST(PostgreSQL, ImplicitTransaction)
 {
-  std::auto_ptr<PostgreSQLDatabase> db(CreateTestDatabase());
+  std::unique_ptr<PostgreSQLDatabase> db(CreateTestDatabase());
 
   ASSERT_FALSE(db->DoesTableExist("test"));
   ASSERT_FALSE(db->DoesTableExist("test2"));
 
   {
-    std::auto_ptr<OrthancDatabases::ITransaction> t(db->CreateTransaction(false));
+    std::unique_ptr<OrthancDatabases::ITransaction> t(db->CreateTransaction(false));
     ASSERT_FALSE(t->IsImplicit());
   }
 
   {
     Query query("CREATE TABLE test(id INT)", false);
-    std::auto_ptr<IPrecompiledStatement> s(db->Compile(query));
+    std::unique_ptr<IPrecompiledStatement> s(db->Compile(query));
     
-    std::auto_ptr<ITransaction> t(db->CreateTransaction(true));
+    std::unique_ptr<ITransaction> t(db->CreateTransaction(true));
     ASSERT_TRUE(t->IsImplicit());
     ASSERT_THROW(t->Commit(), Orthanc::OrthancException);
     ASSERT_THROW(t->Rollback(), Orthanc::OrthancException);
@@ -426,9 +428,9 @@ TEST(PostgreSQL, ImplicitTransaction)
   {
     // An implicit transaction does not need to be explicitely committed
     Query query("CREATE TABLE test2(id INT)", false);
-    std::auto_ptr<IPrecompiledStatement> s(db->Compile(query));
+    std::unique_ptr<IPrecompiledStatement> s(db->Compile(query));
     
-    std::auto_ptr<ITransaction> t(db->CreateTransaction(true));
+    std::unique_ptr<ITransaction> t(db->CreateTransaction(true));
 
     Dictionary args;
     t->ExecuteWithoutResult(*s, args);
@@ -513,3 +515,41 @@ TEST(PostgreSQLIndex, CreateInstance)
   ASSERT_NE(r1.instanceId, r2.instanceId);
 }
 #endif
+
+
+TEST(PostgreSQL, Lock2)
+{
+  std::unique_ptr<PostgreSQLDatabase> db1(CreateTestDatabase());
+  db1->Open();
+
+  ASSERT_FALSE(db1->ReleaseAdvisoryLock(43)); // lock counter = 0
+  ASSERT_TRUE(db1->AcquireAdvisoryLock(43));  // lock counter = 1
+
+  // OK, as this is the same connection
+  ASSERT_TRUE(db1->AcquireAdvisoryLock(43));  // lock counter = 2
+  ASSERT_TRUE(db1->ReleaseAdvisoryLock(43));  // lock counter = 1
+
+  // Try and release twice the lock
+  ASSERT_TRUE(db1->ReleaseAdvisoryLock(43));  // lock counter = 0
+  ASSERT_FALSE(db1->ReleaseAdvisoryLock(43)); // cannot unlock
+  ASSERT_TRUE(db1->AcquireAdvisoryLock(43));  // lock counter = 1
+
+  {
+    std::unique_ptr<PostgreSQLDatabase> db2(CreateTestDatabase());
+    db2->Open();
+
+    // The "db1" is still actively locking
+    ASSERT_FALSE(db2->AcquireAdvisoryLock(43));
+
+    // Release the "db1" lock
+    ASSERT_TRUE(db1->ReleaseAdvisoryLock(43));
+    ASSERT_FALSE(db1->ReleaseAdvisoryLock(43));
+
+    // "db2" can now acquire the lock, but not "db1"
+    ASSERT_TRUE(db2->AcquireAdvisoryLock(43));
+    ASSERT_FALSE(db1->AcquireAdvisoryLock(43));
+  }
+
+  // "db2" is closed, "db1" can now acquire the lock
+  ASSERT_TRUE(db1->AcquireAdvisoryLock(43));
+}
