@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2019 Osimis S.A., Belgium
+ * Copyright (C) 2017-2020 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,7 +21,7 @@
 
 #include "../Plugins/PostgreSQLIndex.h"
 
-#include <Core/Logging.h>
+#include <Logging.h>
 #include <gtest/gtest.h>
 
 OrthancDatabases::PostgreSQLParameters  globalParameters_;
@@ -34,7 +34,7 @@ OrthancDatabases::PostgreSQLParameters  globalParameters_;
 
 TEST(PostgreSQL, Version)
 {
-  ASSERT_STREQ("9.6.1", PG_VERSION);
+  ASSERT_STREQ("13.1", PG_VERSION);
 }
 #endif
 
